package com.jiuqi.util.chinese;

import java.io.Serializable;

/* loaded from: com_jiuqi_util_chinese.jar:com/jiuqi/util/chinese/ChineseDigitUnit.class */
class ChineseDigitUnit implements Cloneable, Serializable {
    private static final char[] SMALL_UNIT = {21313, 30334, 21315};
    private static final char[] BIG_UNIT = {25342, 20336, 20191};
    private static final char[] LARGE_UNIT = {19975, 20159};
    private static String bufferedUnit = null;
    private static String bufferedPower = null;
    private String power;

    public ChineseDigitUnit() {
        this.power = "1";
    }

    public ChineseDigitUnit(long power) {
        power = power < 0 ? -power : power;
        long j = 1;
        while (true) {
            long value = j;
            if (power >= 10) {
                power /= 10;
                j = value * 10;
            } else {
                this.power = String.valueOf(value);
                return;
            }
        }
    }

    public ChineseDigitUnit(String unit) {
        if (unit != null && unit.equals("")) {
            boolean digitString = isDigitString(unit);
            if (digitString) {
                StringBuffer sb = new StringBuffer("1");
                for (int i = 0; i < unit.length() - 1; i++) {
                    sb.append("0");
                }
                this.power = sb.toString();
                return;
            }
            try {
                this.power = valueOf(unit);
                return;
            } catch (NotValidChineseDigitUnitException unused) {
                throw new IllegalArgumentException("单位\"" + unit + "\"既不是一个有效的阿拉伯数字，也不是有效的中文数字单位！");
            }
        }
        throw new IllegalArgumentException("字符串为null或者空字符串！");
    }

    public long longValue() {
        return Long.parseLong(this.power);
    }

    public String chineseValue(boolean useBigChar) {
        return toChineseUnit(this.power, useBigChar);
    }

    public static String valueOf(String value) throws NotValidChineseDigitUnitException {
        long j;
        int i;
        if (value.equals(bufferedUnit)) {
            return bufferedPower;
        }
        long result = 0;
        for (int i2 = 0; i2 < value.length(); i2++) {
            char thisUnit = value.charAt(i2);
            int position = -1;
            int j2 = 0;
            while (true) {
                if (j2 >= SMALL_UNIT.length) {
                    break;
                }
                if (thisUnit != SMALL_UNIT[j2]) {
                    j2++;
                } else {
                    position = j2;
                    break;
                }
            }
            if (position != -1) {
                j = result;
                i = position + 1;
            } else {
                int j3 = 0;
                while (true) {
                    if (j3 >= BIG_UNIT.length) {
                        break;
                    }
                    if (thisUnit != BIG_UNIT[j3]) {
                        j3++;
                    } else {
                        position = j3;
                        break;
                    }
                }
                if (position != -1) {
                    j = result;
                    i = position + 1;
                } else {
                    int j4 = 0;
                    while (true) {
                        if (j4 >= LARGE_UNIT.length) {
                            break;
                        }
                        if (thisUnit != LARGE_UNIT[j4]) {
                            j4++;
                        } else {
                            position = j4;
                            break;
                        }
                    }
                    if (position != -1) {
                        j = result;
                        i = 4 * (position + 1);
                    } else {
                        throw new NotValidChineseDigitUnitException("字符" + thisUnit + "不是一个合法的中文数字单位！");
                    }
                }
            }
            result = j + i;
        }
        StringBuffer sb = new StringBuffer("1");
        for (int i3 = 0; i3 < result; i3++) {
            sb.append("0");
        }
        bufferedUnit = value;
        bufferedPower = sb.toString();
        return sb.toString();
    }

    public static String toChineseUnit(String power, boolean useBigChar) {
        if (isDigitString(power)) {
            int pow = power.length();
            StringBuffer sb = new StringBuffer();
            while (pow > 8) {
                sb.insert(0, LARGE_UNIT[1]);
                pow -= 8;
            }
            while (pow > 4) {
                sb.insert(0, LARGE_UNIT[0]);
                pow -= 4;
            }
            if (pow > 1) {
                if (!useBigChar) {
                    sb.insert(0, SMALL_UNIT[pow - 2]);
                } else {
                    sb.insert(0, BIG_UNIT[pow - 2]);
                }
            }
            return sb.toString();
        }
        throw new IllegalArgumentException("字符串\"" + power + "\"不是一个阿拉伯数字字符串！");
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static boolean isDigitString(String value) {
        for (int i = 0; i < value.length(); i++) {
            char c = value.charAt(i);
            if (!Character.isDigit(c)) {
                return false;
            }
        }
        return true;
    }

    public static boolean isValidChineseDigitUnit(String value) {
        try {
            valueOf(value);
            return true;
        } catch (NotValidChineseDigitUnitException unused) {
            return false;
        }
    }

    public static boolean isLargeUnit(char value) {
        for (int i = 0; i < LARGE_UNIT.length; i++) {
            if (value == LARGE_UNIT[i]) {
                return true;
            }
        }
        return false;
    }

    public Object clone() {
        return new ChineseDigitUnit(this.power);
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (!(obj instanceof ChineseDigitUnit)) {
            return false;
        }
        ChineseDigitUnit unit = (ChineseDigitUnit) obj;
        return this.power.equals(unit.power);
    }

    public int hashCode() {
        int value = super.hashCode();
        if (this.power != null) {
            value ^= this.power.hashCode();
        }
        return value;
    }

    public String toString() {
        return chineseValue(false);
    }
}
